==> eulertools-2.0.0.tar.gz: eulertools-2.0.0/docs/README.md <==
# eulertools: Multilanguage competitive coding toolbox

[![tests][test_badge]][test_url]
[![license][licence_badge]][licence_url]
[![pypi][pypi_badge]][pypi_url]
[![downloads][pepy_badge]][pepy_url]
[![code style: black][black_badge]][black_url]
[![build automation: yam][yam_badge]][yam_url]
[![Lint: ruff][ruff_badge]][ruff_url]

`eulertools` offers a tool to run/test/compare problems in for
competitive programming, or interview preparation, for example from
[Project Euler], [leetcode], [topcoder] and others.

## Features

`eulertools` provides a cli command called `euler` to run, test, and time your solutions.
`eulertools` have miminal requirements on the project stucture, and is able to compare
the timings between solutions in different languages.

For the required project structure, installation instructions, and usage,
please view the detailed [Documentation].

## Links

-   [Documentation]
-   [Changelog]

[test_badge]: https://github.com/spapanik/eulertools/actions/workflows/tests.yml/badge.svg
[test_url]: https://github.com/spapanik/eulertools/actions/workflows/tests.yml
[licence_badge]: https://img.shields.io/github/license/spapanik/eulertools
[licence_url]: https://github.com/spapanik/eulertools/blob/main/LICENSE.txt
[pypi_badge]: https://img.shields.io/pypi/v/eulertools
[pypi_url]: https://pypi.org/project/eulertools
[pepy_badge]: https://pepy.tech/badge/eulertools
[pepy_url]: https://pepy.tech/project/eulertools
[black_badge]: https://img.shields.io/badge/code%20style-black-000000.svg
[black_url]: https://github.com/psf/black
[yam_badge]: https://img.shields.io/badge/build%20automation-yamk-success
[yam_url]: https://github.com/spapanik/yamk
[ruff_badge]: https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/charliermarsh/ruff/main/assets/badge/v1.json
[ruff_url]: https://github.com/charliermarsh/ruff
[Documentation]: https://eulertools.readthedocs.io/en/stable/
[Changelog]: https://github.com/spapanik/eulertools/blob/main/CHANGELOG.rst
[Project Euler]: https://projecteuler.net/
[leetcode]: https://leetcode.com/
[topcoder]: https://www.topcoder.com/

==> eulertools-2.1.0.tar.gz: eulertools-2.1.0/docs/README.md <==
# eulertools: Multilanguage competitive coding toolbox

[![tests][test_badge]][test_url]
[![license][licence_badge]][licence_url]
[![pypi][pypi_badge]][pypi_url]
[![downloads][pepy_badge]][pepy_url]
[![code style: black][black_badge]][black_url]
[![build automation: yam][yam_badge]][yam_url]
[![Lint: ruff][ruff_badge]][ruff_url]

`eulertools` offers a tool to run/test/compare problems in for
competitive programming, or interview preparation, for example from
[Project Euler], [leetcode], [topcoder] and others.

## Features

`eulertools` provides a cli command called `euler` to run, test, and time your solutions.
`eulertools` have miminal requirements on the project stucture, and is able to compare
the timings between solutions in different languages.

For the required project structure, installation instructions, and usage,
please view the detailed [Documentation].

## Links

- [Documentation]
- [Changelog]

[test_badge]: https://github.com/spapanik/eulertools/actions/workflows/tests.yml/badge.svg
[test_url]: https://github.com/spapanik/eulertools/actions/workflows/tests.yml
[licence_badge]: https://img.shields.io/github/license/spapanik/eulertools
[licence_url]: https://github.com/spapanik/eulertools/blob/main/docs/LICENSE.md
[pypi_badge]: https://img.shields.io/pypi/v/eulertools
[pypi_url]: https://pypi.org/project/eulertools
[pepy_badge]: https://pepy.tech/badge/eulertools
[pepy_url]: https://pepy.tech/project/eulertools
[black_badge]: https://img.shields.io/badge/code%20style-black-000000.svg
[black_url]: https://github.com/psf/black
[yam_badge]: https://img.shields.io/badge/build%20automation-yamk-success
[yam_url]: https://github.com/spapanik/yamk
[ruff_badge]: https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/charliermarsh/ruff/main/assets/badge/v1.json
[ruff_url]: https://github.com/charliermarsh/ruff
[Documentation]: https://eulertools.readthedocs.io/en/stable/
[Changelog]: https://github.com/spapanik/eulertools/blob/main/docs/CHANGELOG.md
[Project Euler]: https://projecteuler.net/
[leetcode]: https://leetcode.com/
[topcoder]: https://www.topcoder.com/
